==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/PointSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { PointSeriesDescription } from "./PointSeriesDescription";
/**
 * @hidden
 */
export let PointSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class PointSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (PointSeriesDescriptionMetadata.a == null) {
                PointSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PointSeriesDescriptionMetadata.c(PointSeriesDescriptionMetadata.a);
            }
            if (a.j(PointSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(PointSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
        }
        static d(a) {
            PointSeriesDescriptionMetadata.b(a);
            a.aa("PointSeries", () => new PointSeriesDescription());
            a.z("PointSeries", PointSeriesDescriptionMetadata.a);
        }
    }
    PointSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(PointSeriesDescriptionMetadata, 'PointSeriesDescriptionMetadata');
    PointSeriesDescriptionMetadata.a = null;
    return PointSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/PointSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalAnchoredCategorySeriesDescriptionMetadata } from "./HorizontalAnchoredCategorySeriesDescriptionMetadata";
import { PointSeriesDescription } from "./PointSeriesDescription";
/**
 * @hidden
 */
export let PointSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class PointSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (PointSeriesDescriptionMetadata.a == null) {
                PointSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PointSeriesDescriptionMetadata.c(PointSeriesDescriptionMetadata.a);
            }
            if (a.k(PointSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(PointSeriesDescriptionMetadata.a);
        }
        static c(a) {
            HorizontalAnchoredCategorySeriesDescriptionMetadata.c(a);
        }
        static d(a) {
            PointSeriesDescriptionMetadata.b(a);
            a.ac("PointSeries", () => new PointSeriesDescription());
            a.ab("PointSeries", PointSeriesDescriptionMetadata.a);
        }
    }
    PointSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(PointSeriesDescriptionMetadata, 'PointSeriesDescriptionMetadata');
    PointSeriesDescriptionMetadata.a = null;
    return PointSeriesDescriptionMetadata;
})();
